@@ -62,6 +62,7 @@ Usage::
         DescribePrefixListsPaginator,
         DescribePrincipalIdFormatPaginator,
         DescribePublicIpv4PoolsPaginator,
+        DescribeReplaceRootVolumeTasksPaginator,
         DescribeReservedInstancesModificationsPaginator,
         DescribeReservedInstancesOfferingsPaginator,
         DescribeRouteTablesPaginator,
@@ -233,6 +234,7 @@ Usage::
     describe_prefix_lists_paginator: DescribePrefixListsPaginator = client.get_paginator("describe_prefix_lists")
     describe_principal_id_format_paginator: DescribePrincipalIdFormatPaginator = client.get_paginator("describe_principal_id_format")
     describe_public_ipv4_pools_paginator: DescribePublicIpv4PoolsPaginator = client.get_paginator("describe_public_ipv4_pools")
+    describe_replace_root_volume_tasks_paginator: DescribeReplaceRootVolumeTasksPaginator = client.get_paginator("describe_replace_root_volume_tasks")
     describe_reserved_instances_modifications_paginator: DescribeReservedInstancesModificationsPaginator = client.get_paginator("describe_reserved_instances_modifications")
     describe_reserved_instances_offerings_paginator: DescribeReservedInstancesOfferingsPaginator = client.get_paginator("describe_reserved_instances_offerings")
     describe_route_tables_paginator: DescribeRouteTablesPaginator = client.get_paginator("describe_route_tables")
@@ -335,6 +337,7 @@ from mypy_boto3_ec2.paginator import (
     DescribePrefixListsPaginator,
     DescribePrincipalIdFormatPaginator,
     DescribePublicIpv4PoolsPaginator,
+    DescribeReplaceRootVolumeTasksPaginator,
     DescribeReservedInstancesModificationsPaginator,
     DescribeReservedInstancesOfferingsPaginator,
     DescribeRouteTablesPaginator,
@@ -483,6 +486,7 @@ __all__ = (
     "DescribePrefixListsPaginator",
     "DescribePrincipalIdFormatPaginator",
     "DescribePublicIpv4PoolsPaginator",
+    "DescribeReplaceRootVolumeTasksPaginator",
     "DescribeReservedInstancesModificationsPaginator",
     "DescribeReservedInstancesOfferingsPaginator",
     "DescribeRouteTablesPaginator",
